import { showLoading } from '../constants'
import { IDomEditor } from '@wangeditor/editor'
import { treeContainer, treeData, treeRef, treeSelectedKeys } from '../constants/tree'
import { dropdownConfig, editorRef, editorHtml } from '../constants'
import { getUUID } from '@/utils'
import { compareData, compareLeftContent, compareRightContent, showCompare } from '../constants/compare'
import TextA from '@/assets/file/CES-QEC-V250-A.xml?raw'
import TextB from '@/assets/file/Trans-Convert.xml?raw'
import { nodeSet, contentHoldNode } from '@/configs/node.config'

export const handleCreated = (editor: IDomEditor) => {
    editorRef.value = editor
    handleChange(editor)
}
export const handleClick = (event: any) => {
    const key = getKey(event.target)
    const node = treeContainer.value?.querySelector(`[data-key="${key}"]`)
    node.scrollIntoView({ behavior: 'smooth' })
    treeSelectedKeys.value = [key]
    setEditorActive(key)
}

let lastFocusedId = ''
export const setEditorActive = (key: string, callBack?: Function) => {
    const container = editorRef.value?.getEditableContainer()
    const id = container!.querySelector(`[data-key="${key}"]`)?.getAttribute('id') as string
    if (container) {
        if (lastFocusedId) {
            container.querySelector(`#${lastFocusedId}`)?.classList.remove('bg-primaryColorHover')
        }
        lastFocusedId = id
        container.querySelector(`#${id}`)?.classList.add('bg-primaryColorHover')
    }
    if (callBack) callBack(id)
}

//获取节点的key
export const getKey = (elem: any): string => {
    if (!elem) return ''
    const key = elem?.getAttribute('data-key')
    if (key) {
        return key
    } else {
        elem = elem.parentElement
        return getKey(elem)
    }
}
// 右键
export const handleContextMenu = (event: MouseEvent) => {
    const dom = event.target as HTMLElement
    //递归获取父节点,直到父节点是nodeSet中的数据
    let parent = dom.parentElement
    while (parent) {
        if (nodeSet.includes(parent.tagName as string)) {
            break
        }
        parent = parent.parentElement
    }
    console.log(parent)
    dropdownConfig.show = false
    nextTick(() => {
        dropdownConfig.show = true
        dropdownConfig.x = event.clientX
        dropdownConfig.y = event.clientY
    })
}
// 右键选择
export const handleSelect = (key: string | number) => {
    dropdownConfig.show = false
    editorRef.value?.restoreSelection()
    if (key == 'TaskTitle') {
        const node = { type: 'TaskTitle', dataKey: getUUID(), children: [{ text: 'TaskTitle' }] }
        editorRef.value?.insertNode(node)
    } else if (key == 'TopicTitle') {
        const node = { type: 'TopicTitle', dataKey: getUUID(), children: [{ text: 'TopicTitle' }] }
        editorRef.value?.insertNode(node)
    }
}
export const onClickoutside = () => {
    dropdownConfig.show = false
}
// 编辑器内容变化
export const handleChange = (editor: IDomEditor) => {
    if (editor.getHtml() == '<p><br></p>') return
    const xmlProcessing = useXMLProcessing()
    const res = xmlProcessing.processXML(editor.getHtml().replace(/<p><br><\/p>/g, ''), nodeSet, contentHoldNode)
    treeData.value = res.treeData
    const container = editorRef.value?.getEditableContainer()
    //查找GRAPHIC标签
    const sheet = container?.querySelectorAll('sheet')
    sheet?.forEach((node, index) => {
        let src = 'https://hnaelbtest.hnatechnic.com/mocptest/resource/20250427/76ef8494-de05-43d8-ae71-0fbf27b7f564.png'
        if (index == 0) {
            src = 'https://hnaelbtest.hnatechnic.com/mocptest/resource/20250427/549f74f9-f0bd-48a6-9b01-fa27ea8c28aa.png'
        }
        const img = document.createElement('img')
        img.src = src
        img.style.width = '100%'
        img.style.height = 'auto'
        node.replaceWith(img)
    })
}
// 上传xml
export const uploadXml = async () => {
    const input = document.createElement('input')
    input.type = 'file'
    input.accept = 'application/xml,text/xml'
    input.multiple = false
    input.click()
    input.addEventListener('change', async (event: Event) => {
        const files = (event.target as HTMLInputElement).files
        if (files && files.length > 0) {
            const file = files[0]
            const xmlProcessing = useXMLProcessing()
            showLoading.value = true
            const res = await xmlProcessing.processFile(file, nodeSet, contentHoldNode)
            // console.log(res.treeData[0].node.attributes)
            showLoading.value = false
            editorHtml.value = handleNativeHtml(res.xmlContent)
        }
        input.remove()
    })
}
//xml对比
export const compareXml = () => {
    showCompare.value = true
    compareData.treeOld = ''
    compareData.treeNew = ''
    compareLeftContent.value = ''
    compareRightContent.value = ''
}
//处理原生html标签
export const handleNativeHtml = (html: string) => {
    html = html.replace(/<TABLE(?!\s*\/>)([^>]*)>/g, '<HTML-TABLE data-w-e-type="HTML-TABLE" $1>')
    html = html.replace(/<\/TABLE>/g, '</HTML-TABLE>')
    html = html.replace(/<THEAD(?!\s*\/>)([^>]*)>/g, '<HTML-THEAD data-w-e-type="HTML-THEAD" $1>')
    html = html.replace(/<\/THEAD>/g, '</HTML-THEAD>')
    html = html.replace(/<TBODY(?!\s*\/>)([^>]*)>/g, '<HTML-TBODY data-w-e-type="HTML-TBODY" $1>')
    html = html.replace(/<\/TBODY>/g, '</HTML-TBODY>')
    return html
}
